import { Component, forwardRef, OnChanges } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { CustomInputComponent } from './../../_abstract/custom-input.component';

@Component({
	selector: 'app-checkbutton',
	templateUrl: './checkbutton.component.html',
	styleUrls: ['./checkbutton.component.scss'],
	providers: [
		{
			provide: NG_VALUE_ACCESSOR,
			useExisting: forwardRef(() => CheckbuttonComponent),
			multi: true
		}
	]
})
export class CheckbuttonComponent extends CustomInputComponent implements OnChanges {

	exposeMetaInTemplate: string[] = ['label', 'value', 'disabled', 'checkedValue', 'onChange'];

	value?: string | boolean = true;
	isChecked: boolean;
	disabled = false;
	currentValue: string | boolean;
	checkedValue: string | boolean = true;
	onChange: (val) => {};

	ngOnChanges() {
		this.disabled = this.meta.disabled;
	}

	private toggleChecked(e): void {
		e.target.blur();
		e.preventDefault();
		if (this.disabled) { return; }
		this.isChecked = !this.isChecked;
		this.currentValue = this.isChecked ? this.value || this.checkedValue : false;
		if (typeof this.onChange === 'function') {
			try {
				this.onChange(this.currentValue);
			} catch (e) {
				console.log('ERROR in onChange function');
			}
		}
		this.propagateChange(this.currentValue);
	}

	public writeValue(value: any): void {
		// this.isChecked = (value && value !== 0 && value !== 'false') ? true : false;
		this.isChecked = !!value;
		console.log(this.isChecked);
		this.currentValue = this.isChecked ? this.value || this.checkedValue : false;
	}
}
